@@ -28,7 +28,7 @@ class NxPyDocs():
                             # 'show cdp neighbors',
                             # 'show cdp neighbors detail',
                             # 'show environment',
-                            # 'show interface',
+                            'show interface',
                             # 'show interface status',
                             # 'show interface transceiver',
                             'show inventory',
